@@ -323,6 +323,36 @@ func TestNoCache(t *testing.T) {
 	checkValue(true)
 }
 
+func TestQuiet(t *testing.T) {
+	as := require.New(t)
+
+	cfg := &config.Config{}
+	v, flags := newViper(t)
+
+	checkValue := func(expected bool) {
+		readValue(t, v, cfg, func(cfg *config.Config) {
+			as.Equal(expected, cfg.Quiet)
+		})
+	}
+
+	// default with no flag, env or config
+	checkValue(false)
+
+	// set config value and check that it has no effect
+	// you are not allowed to set no-cache in config
+	cfg.Quiet = true
+
+	checkValue(false)
+
+	// env override
+	t.Setenv("TREEFMT_QUIET", "false")
+	checkValue(false)
+
+	// flag override
+	as.NoError(flags.Set("quiet", "true"))
+	checkValue(true)
+}
+
 func TestOnUnmatched(t *testing.T) {
 	as := require.New(t)
 
@@ -336,7 +366,7 @@ func TestOnUnmatched(t *testing.T) {
 	}
 
 	// default with no flag, env or config
-	checkValue("warn")
+	checkValue("info")
 
 	// set config value
 	cfg.OnUnmatched = "error"
@@ -573,14 +603,6 @@ func TestSampleConfigFile(t *testing.T) {
 	as.Equal([]string{"*.py"}, python.Includes)
 	as.Nil(python.Excludes)
 
-	// elm
-	elm, ok := cfg.FormatterConfigs["elm"]
-	as.True(ok, "elm formatter not found")
-	as.Equal("elm-format", elm.Command)
-	as.Equal([]string{"--yes"}, elm.Options)
-	as.Equal([]string{"*.elm"}, elm.Includes)
-	as.Nil(elm.Excludes)
-
 	// go
 	golang, ok := cfg.FormatterConfigs["go"]
 	as.True(ok, "go formatter not found")
